@@ -3,10 +3,11 @@
 import click
 import logging
 from deployv_addon_gitlab_tools.commands import (
-    check_keys, test_images, upload_image, deployv_tests, push_coverage, build_image, test_image
+    check_keys, test_images, upload_image, deployv_tests, push_coverage,
+    build_image, test_image, check_log
 )
 
-__version__ = "0.2.34"
+__version__ = "0.2.36"
 _logger = logging.getLogger('deployv.' + __name__)
 
 
@@ -33,7 +34,8 @@ for command in [
         deployv_tests.deployv_tests,
         push_coverage.push_coverage,
         build_image.build_image,
-        test_image.test_image
+        test_image.test_image,
+        check_log.check_log
 
 ]:
     gitlab_tools.add_command(command)
