@@ -21,7 +21,8 @@ _cli = Client(timeout=7200)
 TO_SCAN = ['git.vauxoo.com',
            'github.com',
            'gitlab.com',
-           'bitbucket.org']
+           'bitbucket.org',
+           'git.islamicreliefcanada.ca']
 
 
 def pull_images(images):
